// +------------------------------------------------------------------+
// |             ____ _               _        __  __ _  __           |
// |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
// |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
// |           | |___| | | |  __/ (__|   <    | |  | | . \            |
// |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
// |                                                                  |
// | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
// +------------------------------------------------------------------+
//
// This file is part of Check_MK.
// The official homepage is at http://mathias-kettner.de/check_mk.
//
// check_mk is free software;  you can redistribute it and/or modify it
// under the  terms of the  GNU General Public License  as published by
// the Free Software Foundation in version 2.  check_mk is  distributed
// in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
// out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
// PARTICULAR PURPOSE. See the  GNU General Public License for more de-
// ails.  You should have  received  a copy of the  GNU  General Public
// License along with GNU Make; see the file  COPYING.  If  not,  write
// to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
// Boston, MA 02110-1301 USA.

#ifndef opids_h
#define opids_h

#include "config.h"  // IWYU pragma: keep

#define OP_INVALID 0
#define OP_EQUAL 1        // =
#define OP_REGEX 2        // ~
#define OP_EQUAL_ICASE 3  // =~
#define OP_REGEX_ICASE 4  // ~~
#define OP_GREATER 5      // >
#define OP_LESS 6         // <

extern const char *op_names_plus_8[];

// Note: The operators !=, <= and >= are parsed into ! =, ! > and ! <.
// The negation is represented by negating the value of the operator.
// Example >= is represented as -6 (- OP_LESS)

#endif  // opids_h
